import { RedisCommandArgument, RedisCommandArguments } from '.';
export { FIRST_KEY_INDEX } from './ZPOPMIN';
export declare function transformArguments(key: RedisCommandArgument, count: number): RedisCommandArguments;
export { transformSortedSetWithScoresReply as transformReply } from './generic-transformers';
