/// <reference types="node" />
import { Composer } from './interface';
export default class StringComposer implements Composer<string> {
    private decoder;
    private string;
    write(buffer: Buffer): void;
    end(buffer: Buffer): string;
    reset(): void;
}
