import { RedisCommandArgument, RedisCommandArguments } from '.';
export { FIRST_KEY_INDEX, IS_READ_ONLY } from './LCS';
export declare function transformArguments(key1: RedisCommandArgument, key2: RedisCommandArgument): RedisCommandArguments;
export declare function transformReply(): number;
