import { RedisCommandArguments } from '.';
import { SlotRange } from './generic-transformers';
export declare function transformArguments(ranges: SlotRange | Array<SlotRange>): RedisCommandArguments;
export declare function transformReply(): 'OK';
