import { RedisCommandArgument, RedisCommandArguments } from '.';
interface BgSaveOptions {
    SCHEDULE?: true;
}
export declare function transformArguments(options?: BgSaveOptions): RedisCommandArguments;
export declare function transformReply(): RedisCommandArgument;
export {};
