import { RedisCommandArgument, RedisCommandArguments } from '.';
import { LPosOptions } from './LPOS';
export { FIRST_KEY_INDEX, IS_READ_ONLY } from './LPOS';
export declare function transformArguments(key: RedisCommandArgument, element: RedisCommandArgument, count: number, options?: LPosOptions): RedisCommandArguments;
export declare function transformReply(): Array<number>;
