import { RedisCommandArgument, RedisCommandArguments } from '.';
export declare function transformArguments(dump: RedisCommandArgument, mode?: 'FLUSH' | 'APPEND' | 'REPLACE'): RedisCommandArguments;
export declare function transformReply(): 'OK';
