import { RedisCommandArgument } from '.';
export declare const IS_READ_ONLY = true;
export declare function transformArguments(version?: number, ...optionalArguments: Array<number>): Array<string>;
export declare function transformReply(): RedisCommandArgument;
