export declare enum RedisFlushModes {
    ASYNC = "ASYNC",
    SYNC = "SYNC"
}
export declare function transformArguments(mode?: RedisFlushModes): Array<string>;
export declare function transformReply(): string;
