import { RedisCommandArguments } from '.';
export declare function transformArguments(): RedisCommandArguments;
export declare function transformReply(): Array<[
    name: string,
    timestamp: number,
    latestLatency: number,
    allTimeLatency: number
]>;
