interface FailoverOptions {
    TO?: {
        host: string;
        port: number;
        FORCE?: true;
    };
    ABORT?: true;
    TIMEOUT?: number;
}
export declare function transformArguments(options?: FailoverOptions): Array<string>;
export declare function transformReply(): string;
export {};
