import { RedisCommandArguments } from '.';
import { MSetArguments } from './MSET';
export declare const FIRST_KEY_INDEX = 1;
export declare function transformArguments(toSet: MSetArguments): RedisCommandArguments;
export { transformBooleanReply as transformReply } from './generic-transformers';
