import { RedisCommandArgument, RedisCommandArguments } from '.';
export declare function transformArguments(username: RedisCommandArgument, rule: RedisCommandArgument | Array<RedisCommandArgument>): RedisCommandArguments;
export declare function transformReply(): RedisCommandArgument;
