import { RedisCommandArgument, RedisCommandArguments } from '.';
export declare function transformArguments(): RedisCommandArguments;
export declare function transformReply(): Array<RedisCommandArgument>;
