export declare function transformArguments(): Array<string>;
interface TimeReply extends Date {
    microseconds: number;
}
export declare function transformReply(reply: [string, string]): TimeReply;
export {};
