import { RedisCommandArgument, RedisCommandArguments } from '.';
export declare function transformArguments(message?: RedisCommandArgument): RedisCommandArguments;
export declare function transformReply(): RedisCommandArgument;
