export declare enum FailoverModes {
    FORCE = "FORCE",
    TAKEOVER = "TAKEOVER"
}
export declare function transformArguments(mode?: FailoverModes): Array<string>;
export declare function transformReply(): 'OK';
