import { RedisCommandArguments } from '.';
import { CommandRawReply, CommandReply } from './generic-transformers';
export declare const IS_READ_ONLY = true;
export declare function transformArguments(): RedisCommandArguments;
export declare function transformReply(reply: Array<CommandRawReply>): Array<CommandReply>;
