import { RedisCommandArgument, RedisCommandArguments } from '.';
export declare const IS_READ_ONLY = true;
export declare function transformArguments(channels?: Array<RedisCommandArgument> | RedisCommandArgument): RedisCommandArguments;
export declare function transformReply(rawReply: Array<string | number>): Record<string, number>;
