/// <reference types="node" />
import { RedisCommandArguments } from '.';
export declare function transformArguments(timeout: number, mode?: 'WRITE' | 'ALL'): RedisCommandArguments;
export declare function transformReply(): 'OK' | Buffer;
