export declare const FIRST_KEY_INDEX = 1;
export declare const IS_READ_ONLY = true;
interface MemoryUsageOptions {
    SAMPLES?: number;
}
export declare function transformArguments(key: string, options?: MemoryUsageOptions): Array<string>;
export declare function transformReply(): number | null;
export {};
