import { RedisCommandArgument, RedisCommandArguments } from '.';
export { FIRST_KEY_INDEX, IS_READ_ONLY } from './ZRANDMEMBER';
export declare function transformArguments(key: RedisCommandArgument, count: number): RedisCommandArguments;
export declare function transformReply(): Array<RedisCommandArgument>;
