import { RedisCommandArgument, RedisCommandArguments } from '.';
export declare const IS_READ_ONLY = true;
export declare function transformArguments(): RedisCommandArguments;
export declare function transformReply(): RedisCommandArgument | null;
