import { RedisCommandArgument, RedisCommandArguments } from '.';
export declare function transformArguments(name: RedisCommandArgument): RedisCommandArguments;
export declare function transformReply(): RedisCommandArgument;
