import { RedisCommandArgument, RedisCommandArguments } from '.';
export declare const IS_READ_ONLY = true;
export declare function transformArguments(channel: RedisCommandArgument, message: RedisCommandArgument): RedisCommandArguments;
export declare function transformReply(): number;
