import { RedisCommandArgument, RedisCommandArguments } from '.';
import { transformArguments as transformXClaimArguments } from './XCLAIM';
export { FIRST_KEY_INDEX } from './XCLAIM';
export declare function transformArguments(...args: Parameters<typeof transformXClaimArguments>): RedisCommandArguments;
export declare function transformReply(): Array<RedisCommandArgument>;
