export declare enum ClusterSlotStates {
    IMPORTING = "IMPORTING",
    MIGRATING = "MIGRATING",
    STABLE = "STABLE",
    NODE = "NODE"
}
export declare function transformArguments(slot: number, state: ClusterSlotStates, nodeId?: string): Array<string>;
export declare function transformReply(): 'OK';
