import { RedisCommandArgument, RedisCommandArguments } from '.';
export declare function transformArguments(bits?: number): RedisCommandArguments;
export declare function transformReply(): RedisCommandArgument;
