import { RedisCommandArgument, RedisCommandArguments } from '.';
export { FIRST_KEY_INDEX, IS_READ_ONLY } from './HRANDFIELD_COUNT';
export declare function transformArguments(key: RedisCommandArgument, count: number): RedisCommandArguments;
export { transformTuplesReply as transformReply } from './generic-transformers';
