/// <reference types="node" />
import { Composer } from './interface';
export default class BufferComposer implements Composer<Buffer> {
    private chunks;
    write(buffer: Buffer): void;
    end(buffer: Buffer): Buffer;
    reset(): void;
}
