/// <reference types="node" />
import { RedisCommandArguments } from '.';
export declare function transformArguments(value: boolean): RedisCommandArguments;
export declare function transformReply(): 'OK' | Buffer;
