import { evalFirstKeyIndex, EvalOptions } from './generic-transformers';
export declare const FIRST_KEY_INDEX: typeof evalFirstKeyIndex;
export declare function transformArguments(script: string, options?: EvalOptions): Array<string>;
