export declare const FIRST_KEY_INDEX = 1;
export declare function transformArguments(key: string, db: number): Array<string>;
export { transformBooleanReply as transformReply } from './generic-transformers';
