import { RedisCommandArgument, RedisCommandArguments } from '.';
export declare function transformArguments(username: RedisCommandArgument | Array<RedisCommandArgument>): RedisCommandArguments;
export declare function transformReply(): number;
