import { RedisCommandArguments } from '.';
import { FunctionListItemReply, FunctionListRawItemReply } from './generic-transformers';
export declare function transformArguments(pattern?: string): RedisCommandArguments;
export declare function transformReply(reply: Array<FunctionListRawItemReply>): Array<FunctionListItemReply>;
